@@ -322,6 +322,10 @@ pub mod cors;
 #[cfg_attr(docsrs, doc(cfg(feature = "request-id")))]
 pub mod request_id;
 
+#[cfg(feature = "catch-panic")]
+#[cfg_attr(docsrs, doc(cfg(feature = "catch-panic")))]
+pub mod catch_panic;
+
 pub mod classify;
 pub mod services;
 
